@@ -3,27 +3,41 @@ package DateTime::Format::Strptime;
 use strict;
 use warnings;
 
-our $VERSION = '1.75';
+our $VERSION = '1.76';
 
 use Carp qw( carp croak );
 use DateTime 1.00;
-use DateTime::Locale 1.05;
+use DateTime::Locale 1.23;
 use DateTime::Format::Strptime::Types;
 use DateTime::TimeZone 2.09;
+use Exporter ();
 use Params::ValidationCompiler qw( validation_for );
 use Try::Tiny;
 
-use Exporter qw( import );
-
-use Package::DeprecationManager 0.15 -deprecations => {
-    'accessor writers' => '1.58',
-};
-
 our @EXPORT_OK = qw( strftime strptime );
 
 ## no critic (ValuesAndExpressions::ProhibitConstantPragma)
 use constant PERL_58 => $] < 5.010;
 
+# We previously used Package::DeprecationManager which allowed passing of
+# "-api_version => X" on import. We don't want any such imports to blow up but
+# we no longer have anything to deprecate.
+sub import {
+    my $class = shift;
+    my @args;
+    ## no critic (ControlStructures::ProhibitCStyleForLoops)
+    for ( my $i = 0; $i < @_; $i++ ) {
+        if ( $_[$i] eq '-api_version' ) {
+            $i++;
+        }
+        else {
+            push @args, $_[$i];
+        }
+    }
+    @_ = ( $class, @args );
+    goto &Exporter::import;
+}
+
 {
     my $en_locale = DateTime::Locale->load('en');
 
@@ -871,53 +885,11 @@ sub _check_dt {
 
 sub pattern {
     my $self = shift;
-
-    if (@_) {
-        my $pattern = shift;
-        deprecated(
-            feature => 'accessor writers',
-            message => 'Calling pattern() as a writer is deprecated.',
-        );
-
-        my $new;
-        try {
-            $new = $self->_clone_with( pattern => $pattern );
-        }
-        catch {
-            $self->_our_carp($_);
-        }
-
-        return unless $new;
-
-        %{$self} = %{$new};
-    }
-
     return $self->{pattern};
 }
 
 sub locale {
     my $self = shift;
-
-    if (@_) {
-        my $locale = shift;
-        deprecated(
-            feature => 'accessor writers',
-            message => 'Calling locale() as a writer is deprecated.',
-        );
-
-        my $new;
-        try {
-            $new = $self->_clone_with( locale => $locale );
-        }
-        catch {
-            $self->_our_carp($_);
-        }
-
-        return unless $new;
-
-        %{$self} = %{$new};
-    }
-
     return $self->{locale}->can('code')
         ? $self->{locale}->code
         : $self->{locale}->id;
@@ -925,48 +897,9 @@ sub locale {
 
 sub time_zone {
     my $self = shift;
-
-    if (@_) {
-        my $time_zone = shift;
-        deprecated(
-            feature => 'accessor writers',
-            message => 'Calling time_zone() as a writer is deprecated.',
-        );
-
-        my $new;
-        try {
-            $new = $self->_clone_with( time_zone => $time_zone );
-        }
-        catch {
-            $self->_our_carp($_);
-        }
-
-        return unless $new;
-
-        %{$self} = %{$new};
-    }
-
     return $self->{time_zone}->name;
 }
 
-# Only used for deprecated accessors-as-writers feature
-sub _clone_with {
-    my $self = shift;
-
-    return ( ref $self )->new(
-        pattern => $self->{pattern},
-        locale  => $self->{locale},
-        (
-            $self->{time_zone}
-            ? ( time_zone => $self->{time_zone} )
-            : ()
-        ),
-        on_error => $self->{on_error},
-        debug    => $self->{debug},
-        @_,
-    );
-}
-
 sub parse_duration {
     croak q{DateTime::Format::Strptime doesn't do durations.};
 }
@@ -999,16 +932,6 @@ sub _our_croak {
     return;
 }
 
-sub _our_carp {
-    my $self  = shift;
-    my $error = shift;
-
-    return $self->{on_error}->( $self, $error ) if ref $self->{on_error};
-    carp $error if $self->{on_error} eq 'croak';
-    $self->{errmsg} = $error;
-    return;
-}
-
 sub errmsg {
     $_[0]->{errmsg};
 }
@@ -1047,7 +970,7 @@ DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.75
+version 1.76
 
 =head1 SYNOPSIS
 
@@ -1110,7 +1033,7 @@ This is a boolean which disables or enables strict matching mode.
 
 By default, this module turns your pattern into a regex that will match
 anywhere in a string. So given the pattern C<%Y%m%d%H%M%S> it will match a
-string like C<20161214233712Z>. However, this also means that a this pattern
+string like C<20161214233712>. However, this also means that a this pattern
 will match B<any> string that contains 14 or more numbers! This behavior can
 be very surprising.
 
@@ -1471,7 +1394,7 @@ Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 - 2017 by Dave Rolsky.
+This software is Copyright (c) 2015 - 2019 by Dave Rolsky.
 
 This is free software, licensed under:
 
